import { defineConfig,ConfigEnv,loadEnv } from "vite";
import vue from "@vitejs/plugin-vue";
import path, { resolve } from "path"; //这个path用到了上面安装的@types/node
import AutoImport from "unplugin-auto-import/vite";
import Components from "unplugin-vue-components/vite";
import { ElementPlusResolver } from "unplugin-vue-components/resolvers";
import { VantResolver } from "unplugin-vue-components/resolvers";

export default((mode:ConfigEnv) =>{
  const env = loadEnv(mode.mode, process.cwd());
  return defineConfig({
    base: './', //打包路径
    publicDir: resolve('public'), //静态资源服务的文件夹
    plugins: [
      vue(),
      AutoImport({
        resolvers: [ElementPlusResolver()],
      }),
      Components({
        resolvers: [ElementPlusResolver(), VantResolver()],
      }),
    ],
    //这里进行配置别名
    resolve: {
      alias: {
        "@": path.resolve("./src"), // @代替src
      },
    },
    server: {
      host: '0.0.0.0',
      port: env.VITE_PORT as unknown as number,
      open: JSON.parse(env.VITE_OPEN),
      hmr: true,
      proxy: {
          '/dev': {
              target: 'https://c.gelifood.com/index.php/api/',
              ws: true,
              secure: true,
              changeOrigin: true,
              rewrite: (path) => path.replace(/^\/dev/, ''),
          },
      },
  },
  // 打包配置
     build: {
           //浏览器兼容性  "esnext"|"modules"
           target: 'modules',
           //指定输出路径
           outDir: 'dist',
           //生成静态资源的存放路径
           assetsDir: 'assets',
           //启用/禁用 CSS 代码拆分
           cssCodeSplit: true,
           sourcemap: false,
           assetsInlineLimit: 10240,
           // 打包环境移除console.log, debugger
           minify: 'terser',
           terserOptions: {
               compress: {
                   drop_console: true,
                   drop_debugger: true,
               },
           },
           rollupOptions: {
               input: {
                   main: resolve('index.html'),
               },
               output: {
                   entryFileNames: `js/[name]-[hash].js`,
                   chunkFileNames: `js/[name]-[hash].js`,
                   assetFileNames: `[ext]/[name]-[hash].[ext]`,
               },
           },
       },

    
  })
})
// https://vitejs.dev/config/

